DREAM8
==========

DREAM8 had 3 challenges, which we refer to as D8C1, D8C2 and D8C3.

For full details see: http://dreamchallenges.org/project-list/dream8-2013/

Click on the image below to jump to the **synapse page** related to each challenge:

.. figure:: http://dreamchallenges.org/wordpress2/wp-content/uploads/closed_breastcancer1.jpg
  :target: https://www.synapse.org/#!Synapse:syn1720047 
  
  **D8C1** - DREAM 8 - HPN-DREAM Breast Cancer Network Inference Challenge
  
.. figure:: http://dreamchallenges.org/wordpress2/wp-content/uploads/closed_lympho.jpg
    :target:   https://www.synapse.org/#!Synapse:syn1761567 

    **D8C2**: DREAM 8 - NIEHS-NCATS-UNC DREAM Toxicogenetics Challenge,
  
.. figure:: http://dreamchallenges.org/wordpress2/wp-content/uploads/closed_mycoplasma.jpg
    :target:   https://www.synapse.org/#!Synapse:syn1761567

    **D8C3**: DREAM 8 - The Whole-Cell Parameter Estimation DREAM Challenge,


